@@ -8,6 +8,7 @@
 #include <QMetaType>
 #include <QObject>
 #include <QTemporaryFile>
+#include <QDateTime>
 
 class QPixmap;
 
@@ -36,7 +37,7 @@ public:
         qreal pos;
         QString note;
         bool operator<(const Bookmark &other) const {
-            return (part == other.part)? (pos < other.pos): (part < other.part);
+            return (part == other.part)? (pos<other.pos): (part<other.part);
         }
     };
 
@@ -83,7 +84,7 @@ public:
     bool clearDir(const QString &directory);
 
     /** Set last bookmark. */
-    void setLastBookmark(int part, qreal position);
+    void setLastBookmark(int part, qreal position, bool fast = false);
 
     /** Get last bookmark. */
     Bookmark lastBookmark();
@@ -91,6 +92,9 @@ public:
     /** Add bookmark. */
     void addBookmark(int part, qreal position, const QString &note);
 
+    /** Change a given bookmark's note text */
+    void setBookmarkNote(int index, const QString &note);
+
     /** Delete bookmark. */
     void deleteBookmark(int index);
 
@@ -131,8 +135,10 @@ public:
     QString rights;                         //< Rights.
     QString tocPath;                        //< Path to toc NCX file.
     QString coverPath;                      //< Path to cover HTML file.
-    QStringList chapters;                   //< Main navigation items from EPUB.
+    QStringList chapters;                   //< Main navigation items.
     qint64 size;                            //< Size of all parts.
+    QDateTime dateAdded;                    //< Date book added to library.
+    QDateTime dateOpened;                   //< Date book was last read.
 
 signals:
     /** Emitted if @see open() succeeds. */
