@@ -2,6 +2,7 @@
 #define PLATFORM_H
 
 #include <QString>
+#include <QSize>
 
 class QWidget;
 
@@ -18,11 +19,16 @@ public:
     QString version();
     QString downloadDir();
     QString defaultFont();
-    int defaultZoom();
+    static int defaultZoom();
     QString defaultOrientation();
+    void setOrientation(QWidget *widget, const QString &orientation);
     void information(const QString &label, QWidget *parent = 0);
     void showBusy(QWidget *w, bool isBusy);
     QString traceFileName();
+    static int softKeyHeight();
+    static int toolBarIconHeight();
+    static QSize size();
+    static QSize availableSize();
 };
 
 #endif // PLATFORM_H
